@@ -8,7 +8,7 @@ from os import path
 from sphinx.environment.adapters.toctree import TocTree
 from sphinx.util.osutil import ensuredir
 
-from .ext import activity, iframe, youtube
+from .ext import a11y, activity, iframe, youtube
 
 
 def get_nav_entry(list_item):
@@ -26,7 +26,7 @@ def get_nav_entry(list_item):
 def get_block_nav(self, pagename):
     """Get the navigation entries for the top-level TOC entries."""
     toctree = TocTree(self.env).get_toctree_for(pagename, self, collapse=False, maxdepth=-1)
-    return [get_nav_entry(item) for item in toctree.children[0].children]
+    return [get_nav_entry(item) for item in toctree.children[0].children if isinstance(item, list_item)]
 
 
 def get_prev_next_nav(prev_next):
@@ -53,9 +53,10 @@ def get_within_block_nav(self, pagename):
     """Build the within-the-block navigation."""
     toctree = TocTree(self.env).get_toctree_for(pagename, self, collapse=False, maxdepth=-1)
     for top_level in toctree.children[0].children:
-        entry = get_nav_entry(top_level)
-        if entry['current'] or entry['expanded']:
-            return build_nav_tree(self, top_level)
+        if isinstance(top_level, list_item):
+            entry = get_nav_entry(top_level)
+            if entry['current'] or entry['expanded']:
+                return build_nav_tree(self, top_level)
     return None
 
 
@@ -149,6 +150,7 @@ def setup(app):
     """Setup the OU Sphinx theme and extensions."""
     app.add_html_theme('openuniversity', path.abspath(path.dirname(__file__)))
     sphinx.builders.html.StandaloneHTMLBuilder.update_page_context = update_page_context
+    a11y.setup(app)
     activity.setup(app)
     iframe.setup(app)
     youtube.setup(app)
